@@ -1395,10 +1395,19 @@ class IMAPRetrieverBase(RetrieverSkeleton):
         self.log.trace()
         try:
             result, resplist = getattr(self.conn, cmd)(*args)
-        except imaplib.IMAP4.error as o:
+        except (imaplib.IMAP4.error, UnicodeEncodeError) as o:
             if cmd == 'login':
-                # Percolate up
-                raise
+                #raise getmailOperationError('IMAP login failed with: %s.\n'%str(o))
+                try:
+                    user, password = self.conf['username'], self.conf['password']
+                    result, resplist = self.conn.authenticate('PLAIN', lambda x: f'\0{user}\0{password}'.encode('utf-8'))
+                    cmd = "authenticate"
+                except (imaplib.IMAP4.error, UnicodeEncodeError) as oa:
+                    raise getmailOperationError(
+                        'IMAP login failed with: %s.\n\
+                        Tried IMAP authenticate, which also failed with: %s'
+                        % (str(o),str(oa))
+                    )
             else:
                 raise getmailOperationError('IMAP error (%s)' % o)
         if result != 'OK':
@@ -1408,6 +1417,8 @@ class IMAPRetrieverBase(RetrieverSkeleton):
             )
         if cmd.lower().startswith('login'):
             self.log.debug('login command response %s' % resplist + os.linesep)
+        if cmd.lower().startswith('authenticate'):
+            self.log.debug('authenticate command response %s' % resplist + os.linesep)
         else:
             self.log.debug(
                 'command %s response %s'
