@@ -31,30 +31,30 @@ except ImportError: #Py 2.7
 
 __all__ = [
     'address_no_brackets',
-    'change_usergroup',
     'change_uidgid',
-    'format_header',
-    'check_ssl_key_and_cert',
+    'change_usergroup',
     'check_ca_certs',
-    'check_ssl_version',
-    'check_ssl_fingerprints',
     'check_ssl_ciphers',
+    'check_ssl_fingerprints',
+    'check_ssl_key_and_cert',
+    'check_ssl_version',
     'deliver_maildir',
     'eval_bool',
     'expand_user_vars',
+    'format_header',
+    'get_password',
+    'gid_of_uid',
     'is_maildir',
     'localhostname',
     'lock_file',
     'logfile',
     'mbox_from_escape',
     'safe_open',
-    'unlock_file',
-    'gid_of_uid',
-    'uid_of_user',
-    'updatefile',
-    'get_password',
     'tostr',
+    'uid_of_user',
     'unicode',
+    'unlock_file',
+    'updatefile',
 ]
 
 if sys.version_info.major > 2:
@@ -246,7 +246,7 @@ def alarm_handler(*unused):
 def is_maildir(d):
     '''Verify a path is a maildir.
     '''
-    dir_parent = os.path.dirname(d.endswith('/') and d[:-1] or d)
+    dir_parent = os.path.dirname(d.endswith('/') and d[:-1] or d) or '.'
     if not os.access(dir_parent, os.X_OK):
         raise getmailConfigurationError(
             'cannot read contents of parent directory of %s '
